@@ -3,10 +3,13 @@
 import re
 from collections import namedtuple
 
-from .snippets import split_by_regex, findall_regex
 from . import exceptions
+from .snippets import findall_regex, split_by_regex
 
-header = namedtuple("header", "index_path old_path old_version new_path new_version",)
+header = namedtuple(
+    "header",
+    "index_path old_path old_version new_path new_version",
+)
 
 diffobj = namedtuple("diff", "header changes text")
 Change = namedtuple("Change", "old new line hunk")
@@ -582,6 +585,8 @@ def parse_unified_diff(text):
     new = 0
     r = 0
     i = 0
+    old_len = 0
+    new_len = 0
 
     changes = list()
 
@@ -609,12 +614,11 @@ def parse_unified_diff(text):
                 h = None
                 break
 
-        while len(hunk) > 0:
-            c = unified_change.match(hunk[0])
+        for n in hunk:
+            c = unified_change.match(n)
             if c:
                 kind = c.group(1)
                 line = c.group(2)
-                c = None
 
                 if kind == "-" and (r != old_len or r == 0):
                     changes.append(Change(old + r, None, line, hunk_n))
@@ -628,8 +632,6 @@ def parse_unified_diff(text):
                     r += 1
                     i += 1
 
-            del hunk[0]
-
     if len(changes) > 0:
         return changes
 
@@ -833,11 +835,25 @@ def parse_ed_diff(text):
 
                     # I basically have no idea why this works
                     # for these tests.
-                    changes.append(Change(None, old - r + i + k + j, hunk[0], hunk_n,))
+                    changes.append(
+                        Change(
+                            None,
+                            old - r + i + k + j,
+                            hunk[0],
+                            hunk_n,
+                        )
+                    )
                     i += 1
                     j += 1
                 if not e and hunk_kind == "a":
-                    changes.append(Change(None, old - r + i + 1, hunk[0], hunk_n,))
+                    changes.append(
+                        Change(
+                            None,
+                            old - r + i + 1,
+                            hunk[0],
+                            hunk_n,
+                        )
+                    )
                     i += 1
 
                 del hunk[0]
